@@ -5,8 +5,8 @@ var group__spa__log =
       [ "level", "structspa__log.html#aeb76fd47b796f30c75d48512b390cedb", null ]
     ] ],
     [ "spa_log_methods", "structspa__log__methods.html", [
-      [ "log", "structspa__log__methods.html#a88344a842a0a2d026da6858d598dd2fc", null ],
-      [ "logv", "structspa__log__methods.html#a49c560fcbf6a90f7cd2f68963482a82d", null ],
+      [ "log", "structspa__log__methods.html#a7d45621105c15f6dca5549c8cc6920b7", null ],
+      [ "logv", "structspa__log__methods.html#a5b42d0cf1f39f36bb70f513de84e3ece", null ],
       [ "version", "structspa__log__methods.html#a3c9b289423cdd729b13d7b3311f1a637", null ]
     ] ],
     [ "SPA_KEY_LOG_COLORS", "group__spa__log.html#ga5989502b5404e2d6887fe7ecca5bd98e", null ],
@@ -14,13 +14,19 @@ var group__spa__log =
     [ "SPA_KEY_LOG_LEVEL", "group__spa__log.html#ga4b1d870cb0263fec5d974057ff7ff0c6", null ],
     [ "SPA_KEY_LOG_LINE", "group__spa__log.html#gae61e34c11a6ccd1b42d570a2f1b8f018", null ],
     [ "SPA_KEY_LOG_TIMESTAMP", "group__spa__log.html#ga16d4dbdafbf101743358d848406dbc14", null ],
-    [ "SPA_LOG_FUNC", "group__spa__log.html#ga167cdddb37397190a2281a9f185fc124", null ],
+    [ "spa_log_debug", "group__spa__log.html#ga90d35e35eb3b712e6a74f95c89562d72", null ],
+    [ "spa_log_error", "group__spa__log.html#gaecb106a06ce6f59e5f9300e641f222e4", null ],
     [ "SPA_LOG_IMPL", "group__spa__log.html#ga2cb43866ec2798103989dcafd611f28f", null ],
     [ "SPA_LOG_IMPL_DEFINE", "group__spa__log.html#ga9680fab963b6dc9daf3c1cf2464e53f1", null ],
     [ "SPA_LOG_IMPL_INIT", "group__spa__log.html#ga54294a1ab30713deee27d8165fb7bd67", null ],
+    [ "spa_log_info", "group__spa__log.html#ga8aeddf0fbcac9650fcfc23c58cf991d6", null ],
     [ "spa_log_level_enabled", "group__spa__log.html#ga63ba8dd805c9b699e93ecf53ae1efed6", null ],
+    [ "spa_log_log", "group__spa__log.html#gaf070c5875700da68020df3dc6ee66dd2", null ],
+    [ "spa_log_logv", "group__spa__log.html#gaa8b31792643b981ff8a7313b26d9d6db", null ],
+    [ "spa_log_trace", "group__spa__log.html#ga142802024be8a40bef345806d498d6b6", null ],
+    [ "spa_log_trace_fp", "group__spa__log.html#ga2c68f365acc6805c88aa81ec720f4ca8", null ],
+    [ "spa_log_warn", "group__spa__log.html#gaafe9ed56ef18db91a0b25ad7a6ffe620", null ],
     [ "SPA_TYPE_INTERFACE_Log", "group__spa__log.html#gaae4067126110801d47890be91be83c5e", null ],
-    [ "SPA_VERSION_LOG", "group__spa__log.html#gab60b078a5687f091f11d951899e7c270", null ],
     [ "spa_log_level", "group__spa__log.html#ga08076f4c659566e0c3f1a8dee549b63d", [
       [ "SPA_LOG_LEVEL_NONE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da0adcef912e39004ada04bf45a525c0fd", null ],
       [ "SPA_LOG_LEVEL_ERROR", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da9b78d95227c88fe557d5836fef32f114", null ],
@@ -29,21 +35,6 @@ var group__spa__log =
       [ "SPA_LOG_LEVEL_DEBUG", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da87c2c8407ce8ef06f5bbb99ef92cc034", null ],
       [ "SPA_LOG_LEVEL_TRACE", "group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da48610bd0a0ae2d8415da4f761eea2662", null ]
     ] ],
-    [ "fputs", "group__spa__log.html#ga8a1c885cb785c9f71eedd901dd45a9a6", null ],
-    [ "if", "group__spa__log.html#ga0f017daf96477eba2f307929c51033e8", null ],
-    [ "snprintf", "group__spa__log.html#ga79024bdce7c2ceaca6f4fb59fb6c9199", null ],
-    [ "spa_log_impl_logv", "group__spa__log.html#ga0aa748aed35cd2334c5f1805eaeb4b83", null ],
-    [ "SPA_PRINTF_FUNC", "group__spa__log.html#ga42cef3bcf90111d5ca43180e65484c49", null ],
-    [ "SPA_PRINTF_FUNC", "group__spa__log.html#ga85dde34327cd5711f91d82c8b684a999", null ],
-    [ "va_end", "group__spa__log.html#ga36af1f79dd6adf0809c21e76535034d5", null ],
-    [ "va_start", "group__spa__log.html#gae0186a335bb9d3688e42cbd7ca07e99c", null ],
-    [ "vsnprintf", "group__spa__log.html#gad4f5c47bfe6859de770e587520e53cd9", null ],
-    [ "args", "group__spa__log.html#ga2347a63632ac764820ccb52d2cf5ac87", null ],
-    [ "basename", "group__spa__log.html#ga95970423d0277feeb449008fa45bf6b3", null ],
-    [ "file", "group__spa__log.html#ga8222126a0a2451cd8396344b236b2d39", null ],
-    [ "fmt", "group__spa__log.html#gabae42996042422cd8fb73f0ca138c5b1", null ],
-    [ "func", "group__spa__log.html#ga62e3cde378b9a7d7e209c0b4da38c361", null ],
-    [ "line", "group__spa__log.html#gaf2db228b8db75ec2c346cbb391a3d82b", null ],
-    [ "location", "group__spa__log.html#ga220ed03dba6a8acc7559f4036381c957", null ],
-    [ "text", "group__spa__log.html#gaff35cb1ec2fb3a5cdf9a0ea02119789d", null ]
+    [ "spa_log_impl_log", "group__spa__log.html#ga3ffa62bd1aa9a79fc65062d141cd4b4f", null ],
+    [ "spa_log_impl_logv", "group__spa__log.html#gac0dca8f108e95ac22351c85cf6134082", null ]
 ];
\ No newline at end of file
