@@ -25,9 +25,14 @@
 var NAVTREE =
 [
   [ "PipeWire", "index.html", [
+    [ "Overview", "page_overview.html", null ],
     [ "PipeWire", "page_pipewire.html", "page_pipewire" ],
     [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
-    [ "API Documentation", "page_api.html", "page_api" ],
+    [ "Media Session", "page_media_session.html", "page_media_session" ],
+    [ "API Documentation", "page_api.html", [
+      [ "Core API", "page_api.html#page_core_api", null ],
+      [ "Implementation API", "page_api.html#page_implementation_api", null ]
+    ] ],
     [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
     [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
     [ "Modules", "modules.html", "modules" ],
@@ -57,41 +62,44 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"alloc_8h.html",
-"filter_8c.html#ada9d2a0ba9c7d74575127151112ddd63",
-"group__pw__context.html#ga9fa7b0905bf18003532e4740050caf09",
-"group__pw__filter.html#ga7aefc7ac2b8293acd783681cdedf954a",
-"group__pw__impl__factory.html#gabab4bb8ff4f065c4c8b931668a3efcee",
-"group__pw__keys.html#ga38e8da2c19e9cd1acf5823865f6e9742",
-"group__pw__link.html#gga7859f6eb040fead1673d0214b83b445ba2ae1f2004f19f37a37c6fb21ccc7157b",
-"group__pw__node.html#gac493839c0b0a1d0b935969f2e990a2df",
-"group__pw__protocol.html#gaedaad565d0021ebcffe1b8699d150174",
-"group__pw__thread__loop.html#ga4b32a1682ab076c733bed42808037328",
-"group__spa__buffer.html#gae0a9f08b948a42aff3229c3b23621a8e",
-"group__spa__graph.html#gae0f7fcfba547dccea55d8fac7ba1918e",
-"group__spa__keys.html#gaec49a8bf593696ff1aa0fc19d561d414",
-"group__spa__node.html#ga7e7c8de3573cd643ee813c35ed254c35",
-"group__spa__param.html#ga34e21602288516fac10361e62d19f03f",
-"group__spa__param.html#gadb3f6f5943b9feaac25ee1bab8dd3966",
-"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbca26f85a091cab1b547becd485c06eb5bb",
-"group__spa__param.html#gga9c37ad62772233835d6bf5083a9e4613a8963cad1c04ca50e2aeeeab46061388e",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa8202a887ffd549599100a69e4bc2a694",
-"group__spa__param.html#ggad9433d39b763912a0fbfabad99c6b202a459f24d7d141f3a602d6eeb777446bc3",
-"group__spa__pod.html#ga5dde9b79f1bdead067ff022b8eb6a564",
-"group__spa__pod.html#gad43b4190b7cd57021a25b75d326d968e",
-"group__spa__support.html#ga94394c9aeeccf55a71dc8b786e674f40",
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635acfb1d7904ddafd3c67dcdd49410bb05a",
-"group__spa__utils.html#gab2f81c97caf8615cf3d9399aec7ee601",
-"introspect_8c.html#a2e5159416cb78f5da8586daea8a75085",
-"module-session-manager_8c.html#a96b5d25b2f981f7be31b35b032750236",
-"param_2audio_2format_8h.html",
-"structfactory__data.html#a0cd1c42e0467448131964c80afd4996c",
-"structmempool.html#a673a591782022241697d49fe985eb7c7",
-"structpw__factory__methods.html#af8cbd6088a874710de9c066169a75d6a",
-"structpw__registry__events.html#a9a62b37a711f65f1014cb27b92ae2689",
-"structspa__graph__node.html#af4ae9586aa3d544a48414987f1839a67",
-"structspa__param__info.html#addb9012c8b7f7db49a4d20ff4569be79",
-"structstream.html#a234356f9ddb74bc10ccdf7f8abf439e8"
+"access-flatpak_8c.html",
+"dbus_8h.html#a3b4641d430f6892c79f6a02284349dbf",
+"group__pw__client.html#ga1144b60d4d77eb5b5bda140e6dd31e13",
+"group__pw__filter.html",
+"group__pw__impl__device.html#ga5ad9e42ea1d048840b5ef3785ff5034d",
+"group__pw__keys.html#ga18a9e0e59cd1a02e6c444edae293f887",
+"group__pw__keys.html#gaedf51309856ddd63ceb49dd66f047f30",
+"group__pw__memblock.html#gga1daf40887c9a63347e9c59822287747aac3e5ceea50faacf9d2aac1670f07fd65",
+"group__pw__properties.html#gaf140f16cfea836559f783f942cfa247d",
+"group__pw__stream.html#gab2ef0e28a1e91816f8015ef9814d18f7",
+"group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea61da86daedb6b8a14a66d067d6a5f80b",
+"group__spa__device.html#gae5a43b17b5a707684dfedb342082ef58",
+"group__spa__keys.html#ga5fe280d124abe3a56346781116908033",
+"group__spa__node.html#ga3d829ade49e9ca5053fc77ba57ea5b0f",
+"group__spa__param.html#ga24bd9414a34ba30e9c0f0ad99b86e427",
+"group__spa__param.html#gac453d82f4058f782084269adfdee4d6f",
+"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0a92abe760ab85d38bf142d18a41e28089",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcae65a88bd9de18b87e5203f00e704eda7",
+"group__spa__param.html#ggaaa66f9e8b1228f1ef1f2630d8d9c5ab5a6d7c25839d6f085a19aa12ca93b2032c",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaab2a1b460a366ad936a33e4f8a1243087",
+"group__spa__param.html#ggaef4025eec20c863b29c7ae07bb3c8d44af7177480c59ea9898cbc421d8740681e",
+"group__spa__pod.html#ga6a89f83c7b14e392bcdaa3c1f2d736ab",
+"group__spa__pod.html#gaea71c973cc38a58e1efd3ab257278d72",
+"group__spa__support.html#gaab4122dc40f03111652545e70ee32b7c",
+"group__spa__utils.html#ga1454d578034f980cbb9f6980f73da335",
+"group__spa__utils.html#gac8080acabcd35c560a15df5e1801afa1",
+"latency-utils_8h.html#a0d0d7d22631ed4d31967a8b005ade6bb",
+"module-pulse-tunnel_8c.html#ae6e3e571584fb00b0f14398e5dcd30bb",
+"page_objects_design.html#autotoc_md100",
+"pod_2pod_8h_source.html",
+"structendpoint.html",
+"structimpl.html#ab3e2f70923316ba1971f4c451fd56cec",
+"structparam.html#a097d5385b4cce1a839a764a2b43c0323",
+"structpw__impl__node__events.html#aaf15bbdebaa2b67dd31ba4c3d56cebc6",
+"structresource__data.html#a5e0db18b4c73cb00fb7ac001fe016198",
+"structspa__i18n__methods.html#aa6a71edc71368a5cd323536ae38e836e",
+"structspa__pod__control.html#adeb12535d89c6cfd05a27edf7c981e4e",
+"structstream.html#ac5c81fe4d3d48b283d1379d45b92cccd"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
