@@ -1,5 +1,74 @@
 var NAVTREEINDEX35 =
 {
+"structspa__i18n__methods.html#aa6a71edc71368a5cd323536ae38e836e":[7,47,7,1],
+"structspa__interface.html":[7,51,1],
+"structspa__interface.html#a2572eec5caf615f77e143013373cdcdf":[7,51,1,2],
+"structspa__interface.html#a99da3754855d6dd1430d21ed97fa0bfb":[7,51,1,1],
+"structspa__interface.html#ae748ef778a029468d301c3727c80a85b":[7,51,1,0],
+"structspa__interface__info.html":[7,49,1],
+"structspa__interface__info.html#acdbeeba8f234386bc1a937604c234e40":[7,49,1,0],
+"structspa__io__buffers.html":[7,44,0],
+"structspa__io__buffers.html#a1364df7bc201533525e5a4fa54f444fe":[7,44,0,1],
+"structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b":[7,44,0,0],
+"structspa__io__clock.html":[7,44,3],
+"structspa__io__clock.html#a3242b88552347adc2e406b75f8136060":[7,44,3,5],
+"structspa__io__clock.html#a4813e6c9101d56eb1f3ac2e9eda1d8c8":[7,44,3,8],
+"structspa__io__clock.html#a69e87d1c701c450b089cd5ec8b51d855":[7,44,3,4],
+"structspa__io__clock.html#a726264b491673c896b53038752149ecb":[7,44,3,6],
+"structspa__io__clock.html#a96d1fa8bd97bb1a840403a103853673e":[7,44,3,9],
+"structspa__io__clock.html#aaddd01ce3e78da42c39efdeab2180035":[7,44,3,10],
+"structspa__io__clock.html#ab3d44cc4e16a47abd913553c3b977051":[7,44,3,2],
+"structspa__io__clock.html#ab639d1a64a22eecfa76ca04001bc163d":[7,44,3,3],
+"structspa__io__clock.html#af384237834c65792f29ccfd3fadfeefe":[7,44,3,1],
+"structspa__io__clock.html#af53218491c71ee19db11966bb16269ce":[7,44,3,7],
+"structspa__io__clock.html#af8fa38eef9a514c13306bd01da06e776":[7,44,3,0],
+"structspa__io__latency.html":[7,44,5],
+"structspa__io__latency.html#a017f13089f0f6847cd70e62d725bd99c":[7,44,5,1],
+"structspa__io__latency.html#a5f23744c90a1dc0e9f0c1e067b8d390a":[7,44,5,0],
+"structspa__io__latency.html#aebb31ddb5622017843ee612c7c66f32a":[7,44,5,2],
+"structspa__io__memory.html":[7,44,1],
+"structspa__io__memory.html#a25a75f4edf0631a335b0dfd55c214f3e":[7,44,1,2],
+"structspa__io__memory.html#a8ad18bb75b7dda83388267077331068c":[7,44,1,0],
+"structspa__io__memory.html#af7c688ea663d461d5c880d0629c7fa49":[7,44,1,1],
+"structspa__io__position.html":[7,44,10],
+"structspa__io__position.html#a0e69b290ceddaa228852e517d67a8ff8":[7,44,10,0],
+"structspa__io__position.html#a112b0de264eccfba2c44c9a4a917b83d":[7,44,10,5],
+"structspa__io__position.html#a576f55a0a4a9b468cedb3c4ccb41a0c4":[7,44,10,4],
+"structspa__io__position.html#a6381154ac49e6f6f37c2a7d65366b7b8":[7,44,10,1],
+"structspa__io__position.html#a6b6da4b94ab7924dda2007712ff2e8f1":[7,44,10,3],
+"structspa__io__position.html#afa5a197f2a03c7b71ed7d99bcd3a3718":[7,44,10,2],
+"structspa__io__range.html":[7,44,2],
+"structspa__io__range.html#a2a824a298a2e459bb719ed29f57de141":[7,44,2,2],
+"structspa__io__range.html#adac0f561e72d269206216a3327720ff7":[7,44,2,0],
+"structspa__io__range.html#af3d7c25e34fd60458e8ca8cfa1067c92":[7,44,2,1],
+"structspa__io__rate__match.html":[7,44,11],
+"structspa__io__rate__match.html#a2ef8495597b9368305657a6202944046":[7,44,11,2],
+"structspa__io__rate__match.html#a7b89f4c442e2856faf64abeec186050e":[7,44,11,1],
+"structspa__io__rate__match.html#a8f9575e69576c942758927acba7daeef":[7,44,11,3],
+"structspa__io__rate__match.html#a9d0be859f40cffcebe7b829d19fcacee":[7,44,11,0],
+"structspa__io__rate__match.html#ad8a395240a4b89d6be0e67538cf6ad5c":[7,44,11,4],
+"structspa__io__segment.html":[7,44,9],
+"structspa__io__segment.html#a6b7f7b35362210bbb0548ce4ab463e12":[7,44,9,1],
+"structspa__io__segment.html#a6ba7bf8b5ba9725546b59b1918f49cc7":[7,44,9,2],
+"structspa__io__segment.html#aa0c906a4de1d90ec5042826b14742301":[7,44,9,3],
+"structspa__io__segment.html#ab725d4cd7f8cb1a44abe185ac504fd1c":[7,44,9,4],
+"structspa__io__segment.html#ac4988f1d377a80a859eb45771f3317fb":[7,44,9,7],
+"structspa__io__segment.html#ad525d9a6f0185e329abc7e89fe394cfd":[7,44,9,0],
+"structspa__io__segment.html#af9ec3a1565e77b1ad781376b758b58c3":[7,44,9,6],
+"structspa__io__segment.html#afcce41ecba3439e02ac35e0b28962346":[7,44,9,5],
+"structspa__io__segment__bar.html":[7,44,7],
+"structspa__io__segment__bar.html#a212f71e2e8b5587d48f4a71151ebdda5":[7,44,7,0],
+"structspa__io__segment__bar.html#a23933e48afa26296c4b2c2df6470bb12":[7,44,7,4],
+"structspa__io__segment__bar.html#a5398027b6c636c287b2df47239b6b9e3":[7,44,7,1],
+"structspa__io__segment__bar.html#a65f1a61b7161bc2ddfb12e2bec1c51d3":[7,44,7,5],
+"structspa__io__segment__bar.html#ad6d079e00b9b7428ab66c7f7fc5e0a5e":[7,44,7,3],
+"structspa__io__segment__bar.html#af6cb2a9476c6fda23897ed5d45b3f2d4":[7,44,7,6],
+"structspa__io__segment__bar.html#afaad39c0e35dbd2e4fc075a93914341f":[7,44,7,2],
+"structspa__io__segment__video.html":[7,44,8],
+"structspa__io__segment__video.html#a4f9acf42fec13d66072ac47ca9aad116":[7,44,8,8],
+"structspa__io__segment__video.html#a500d2d64d490ad483be879cb40b799b4":[7,44,8,2],
+"structspa__io__segment__video.html#a9c45645d7e6aa9aea4508336dd87d17d":[7,44,8,0],
+"structspa__io__segment__video.html#abb72f2853693bb3cfad27520b41f3248":[7,44,8,1],
 "structspa__io__segment__video.html#ad9a1cecce33ac8e1c02532188fe51b5f":[7,44,8,4],
 "structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db":[7,44,8,5],
 "structspa__io__segment__video.html#ae03652e1ab2e76a1a03a63d7bd0fcc99":[7,44,8,7],
@@ -138,11 +207,11 @@ var NAVTREEINDEX35 =
 "structspa__node__methods.html#ac43bffc3912889ba2c35c8fe7c7142db":[7,44,19,9],
 "structspa__node__methods.html#accf0d924064ab5c9c1cdde7d0013232c":[7,44,19,10],
 "structspa__node__methods.html#af04906b32eb2e2862e8e2e2b0ef71f0c":[7,44,19,6],
-"structspa__param__info.html":[7,45,4],
-"structspa__param__info.html#a1fcfd641de4a963a797da64eebfe7771":[7,45,4,0],
-"structspa__param__info.html#aafe96bbf409564bcce653d58fffb40cf":[7,45,4,3],
-"structspa__param__info.html#ad470ae46aca7e354753efbb1019f34fe":[7,45,4,1],
-"structspa__param__info.html#addb9012c8b7f7db49a4d20ff4569be79":[7,45,4,2],
+"structspa__param__info.html":[7,45,5],
+"structspa__param__info.html#a1fcfd641de4a963a797da64eebfe7771":[7,45,5,0],
+"structspa__param__info.html#aafe96bbf409564bcce653d58fffb40cf":[7,45,5,3],
+"structspa__param__info.html#ad470ae46aca7e354753efbb1019f34fe":[7,45,5,1],
+"structspa__param__info.html#addb9012c8b7f7db49a4d20ff4569be79":[7,45,5,2],
 "structspa__pod.html":[7,46,10],
 "structspa__pod.html#a3f7077ea0a9d9fedac8b7ba74cb23408":[7,46,10,1],
 "structspa__pod.html#ad7c483f4a522ca9bf9703f7d5baf1398":[7,46,10,0],
@@ -180,74 +249,5 @@ var NAVTREEINDEX35 =
 "structspa__pod__choice__body.html#a24335975777563cb1c8be5df46ed8aca":[7,46,24,2],
 "structspa__pod__choice__body.html#aa81807e624ebb3832d6fcb0e2a88cb11":[7,46,24,1],
 "structspa__pod__control.html":[7,46,33],
-"structspa__pod__control.html#ab3d78b052b6fbcba7e2d0f543e7c4dac":[7,46,33,2],
-"structspa__pod__control.html#adeb12535d89c6cfd05a27edf7c981e4e":[7,46,33,1],
-"structspa__pod__control.html#ae2a97b90cef2051c5bc8fa6db940179d":[7,46,33,0],
-"structspa__pod__double.html":[7,46,16],
-"structspa__pod__double.html#a3cd088027c7a855edf33339909b0207a":[7,46,16,1],
-"structspa__pod__double.html#ade75ab6437b765fba0c53bb395271a3e":[7,46,16,0],
-"structspa__pod__fd.html":[7,46,31],
-"structspa__pod__fd.html#a1158a743a7aace37f7490d426bb72c92":[7,46,31,1],
-"structspa__pod__fd.html#a30053416214092ba7fb4f8411c4ab3a1":[7,46,31,0],
-"structspa__pod__float.html":[7,46,15],
-"structspa__pod__float.html#a84f5624baada7889f840a015eb2ef6c7":[7,46,15,0],
-"structspa__pod__float.html#a858e59d880b7e0cd076a0c178a576894":[7,46,15,1],
-"structspa__pod__float.html#af197d9ca01cc60ca6280e0c0a18a2c90":[7,46,15,2],
-"structspa__pod__fraction.html":[7,46,20],
-"structspa__pod__fraction.html#ad4721083814a2b28b47ba639cc0c40a6":[7,46,20,1],
-"structspa__pod__fraction.html#ad56b6e9e60a4757fb1b78f86c2604eba":[7,46,20,0],
-"structspa__pod__frame.html":[7,46,7],
-"structspa__pod__frame.html#a33639010072a6ae1c60f0abb559d0197":[7,46,7,3],
-"structspa__pod__frame.html#a3af1eba573563e63ed9d5fa9b3246795":[7,46,7,1],
-"structspa__pod__frame.html#a51486db1e9f9e886bc0b0858321f1252":[7,46,7,2],
-"structspa__pod__frame.html#aedaebc9933fd5e625c622c3a0f1f2d64":[7,46,7,0],
-"structspa__pod__id.html":[7,46,12],
-"structspa__pod__id.html#a6313b9440a92ad53fa8cdd7a2902b817":[7,46,12,2],
-"structspa__pod__id.html#aa884f5dc42c8a5e8ec17d2a3a66be2ea":[7,46,12,0],
-"structspa__pod__id.html#af8623276726ff78da3bc0f7a8c0bba1b":[7,46,12,1],
-"structspa__pod__int.html":[7,46,13],
-"structspa__pod__int.html#a68d3e9d0f9aff4aa84a907a9d8ff07c8":[7,46,13,1],
-"structspa__pod__int.html#a74ea15dcbf22eddbe16372ad50392ed3":[7,46,13,0],
-"structspa__pod__int.html#ab0f590008a307cc732cba65d45b62299":[7,46,13,2],
-"structspa__pod__long.html":[7,46,14],
-"structspa__pod__long.html#a6a21d96d55e7dcbb392d1058411ec861":[7,46,14,1],
-"structspa__pod__long.html#a8b04bfc3d7876362001efa4f3585f186":[7,46,14,0],
-"structspa__pod__object.html":[7,46,28],
-"structspa__pod__object.html#a48beaa7536f4c339aac23729c42a64f3":[7,46,28,1],
-"structspa__pod__object.html#a5432f079d6ffcb0d2f0baee8a130219a":[7,46,28,0],
-"structspa__pod__object__body.html":[7,46,27],
-"structspa__pod__object__body.html#a9f69ed05dcb33536cb39a861631056a8":[7,46,27,1],
-"structspa__pod__object__body.html#aae0deac8b4710eb26e5fc711896aac25":[7,46,27,0],
-"structspa__pod__parser.html":[7,46,9],
-"structspa__pod__parser.html#a063ba699d1129ec01a15af8623d83441":[7,46,9,2],
-"structspa__pod__parser.html#a133bcad805d3b0cbb5cf531af5bf2df8":[7,46,9,3],
-"structspa__pod__parser.html#a4573bb26e3ca5a5df90101715117ddb4":[7,46,9,1],
-"structspa__pod__parser.html#aa910ae08071e719f1eb318c5fd772fb3":[7,46,9,0],
-"structspa__pod__parser__state.html":[7,46,8],
-"structspa__pod__parser__state.html#a7d20db21de9472df961d8b2da5845ea0":[7,46,8,2],
-"structspa__pod__parser__state.html#a88566be69781e492f2927a83429d0d28":[7,46,8,0],
-"structspa__pod__parser__state.html#acf6a430c72bd19259ecbda4643d4b2cf":[7,46,8,1],
-"structspa__pod__pointer.html":[7,46,30],
-"structspa__pod__pointer.html#a09512c2a62eecc6518a7921d4cb0c2a7":[7,46,30,0],
-"structspa__pod__pointer.html#a1aefb7792b75ea7882c273abf8a2edce":[7,46,30,1],
-"structspa__pod__pointer__body.html":[7,46,29],
-"structspa__pod__pointer__body.html#a2b72ed680f7e85d988498503dc66df7e":[7,46,29,2],
-"structspa__pod__pointer__body.html#a2c444fd3eda0725199a91713c7b5676c":[7,46,29,0],
-"structspa__pod__pointer__body.html#afb961dfc1e63a4ec811af33c4183ecaa":[7,46,29,1],
-"structspa__pod__prop.html":[7,46,32],
-"structspa__pod__prop.html#a1d32ef4e73f00e16b07a0cecd3f18fe0":[7,46,32,1],
-"structspa__pod__prop.html#a5f3d78759992c01a760d12743446e8b6":[7,46,32,0],
-"structspa__pod__prop.html#aa5b6f5944e22f135b02594cc173799bb":[7,46,32,2],
-"structspa__pod__rectangle.html":[7,46,19],
-"structspa__pod__rectangle.html#a03b8318f1784bbd03fad4b7187b18c9e":[7,46,19,0],
-"structspa__pod__rectangle.html#a3599080e445b31f812cc4563be10c2ed":[7,46,19,1],
-"structspa__pod__sequence.html":[7,46,35],
-"structspa__pod__sequence.html#abaef5cba65ad23552570ff78c550838f":[7,46,35,1],
-"structspa__pod__sequence.html#ad699555cf7c8114347524399f2a8b163":[7,46,35,0],
-"structspa__pod__sequence__body.html":[7,46,34],
-"structspa__pod__sequence__body.html#adcbb3a7881352555c1a9340662f25c77":[7,46,34,0],
-"structspa__pod__sequence__body.html#ae83a44c4123cc5dc4450a985d4c4445d":[7,46,34,1],
-"structspa__pod__string.html":[7,46,17],
-"structspa__pod__string.html#aa7b8596a64741c1f0b728bc066643c79":[7,46,17,0],
-"structspa__pod__struct.html":[7,46,26]
+"structspa__pod__control.html#ab3d78b052b6fbcba7e2d0f543e7c4dac":[7,46,33,2]
 };
