@@ -1,17 +1,26 @@
 var structport =
 [
+    [ "audio_data", "structport.html#aa215ae1992be530cc074f200caf00fa7", null ],
     [ "buffers", "structport.html#aaa6d523b2c998b888138dcdcb18d397f", null ],
     [ "change_mask_all", "structport.html#aa8ed2e0db384f42ae3d04973e4911b8f", null ],
+    [ "control_data", "structport.html#a118c67f52a1adb25e7cd16add16366d0", null ],
     [ "dequeued", "structport.html#ac45244979760253df1740108c336f6f9", null ],
     [ "direction", "structport.html#a9127d87e211ab1e96252f5aad3642e31", null ],
+    [ "external", "structport.html#a13ec9541822748b5d95662586aa8a6a2", null ],
     [ "filter", "structport.html#ac949585a62ff1dddea6d14108e7cc79d", null ],
     [ "flags", "structport.html#a8390947d3f5b1d1044f6409b58ce5858", null ],
     [ "id", "structport.html#a88f922ca293a694a7db5271fa8cb111b", null ],
+    [ "idx", "structport.html#a25c91e279c4010380dca168731399c7e", null ],
     [ "info", "structport.html#a027f7e706ad0c4596ecf74e88e7e9175", null ],
     [ "io", "structport.html#a020d18d2bc88abde0311fbbd92f14245", null ],
+    [ "latency", "structport.html#a60c9af9665125c0a5e615c45b96e99ed", null ],
     [ "link", "structport.html#a799a4a2207955ee616b20061613fa473", null ],
+    [ "link_list", "structport.html#a1a17a345acb57266e6a99c36f9ac3f18", null ],
     [ "n_buffers", "structport.html#a15d03a418dc232b500f6c3ae18d3608f", null ],
+    [ "n_links", "structport.html#a0c2f4ff46c8e8d6b5ca9f5988ff591fe", null ],
+    [ "node", "structport.html#a8b1180e29775b20a2174b6536ed45e0a", null ],
     [ "node", "structport.html#ac663ef1036c36d74889a279913240f57", null ],
+    [ "p", "structport.html#a2fa8e01bd55b734a6ba7ba6e1463d185", null ],
     [ "param_list", "structport.html#ae589757c86279321884bc16237322053", null ],
     [ "params", "structport.html#a5722499d0807c0577794e09bf98cf27d", null ],
     [ "port", "structport.html#af551c255639f6667830b6442f7c435e1", null ],
